@@ -5,30 +5,40 @@ use warnings;
 
 =head1 NAME
 
-  Bio::DOOP::Cluster - DoOP cluster object
+Bio::DOOP::Cluster - DoOP cluster object
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 SYNOPSIS
 
-  This object represents a cluster. You can access the properties through the methods.
-
-  Usage:
-
   $cluster = Bio::DOOP::Cluster->new($db,"81007400","500");
   print $cluster->get_cluster_id;
 
 =head1 DESCRIPTION
+  
+This object represents a cluster. You can access its properties through the methods.
 
 =head1 AUTHORS
 
-  Tibor Nagy, Godollo, Hungary and Endre Sebestyen, Martonvasar, Hungary
+Tibor Nagy, Godollo, Hungary and Endre Sebestyen, Martonvasar, Hungary
+
+=head1 METHODS
+
+=head2 new
+
+Creates a new cluster object from the cluster id and promoter type. Every promoter cluster has a unique
+identifier. This is the cluster id. There are three promoter sizes (500,1000,3000 bp), so a unique
+cluster is identified by two parameters : cluster id and promoter type.
+
+Return type: Bio::DOOP::Cluster object
+
+  $cluster = Bio::DOOP::Cluster->new($db,"8010110","500");
 
 =cut
 
@@ -59,6 +69,17 @@ sub new {
   return ($self);
 }
 
+=head2 new_by_id
+
+Used by internal MySQL queries.
+
+Return type: Bio::DOOP::Cluster object
+
+  Bio::DOOP::Cluster->new_by_id($db,"2453");
+
+=cut
+
+
 sub new_by_id {
   my $self                 = {};
   my $dummy                = shift;
@@ -86,43 +107,15 @@ sub new_by_id {
   return ($self);
 }
 
-=head1 METHODS
-
-=head2 new
-
-  $cluster = Bio::DOOP::Cluster->new($db,"8010110","500");
-
-  Create a new cluster object from the cluster id and promoter type. Every promoter cluster has a unique
-  identifier. This is the cluster id. There are three promoter sizes (500,1000,3000 bp), so the unique
-  cluster is identified by two parameters : cluster id and promoter type.
-
-  Return type :
-
-  Bio::DOOP::Cluster object
-
-=cut
-
-=head2 new_by_id
-
-  Bio::DOOP::Cluster->new_by_id($db,"2453");
-
-  Used by internal MySQL queries.
-  Return type :
-
-  Bio::DOOP::Cluster object
-
-=cut
 
 =head2 get_id
 
+Returns the MySQL id of the cluster
+
+Return type: string
+
   $cluster_id = $cluster->get_id;
 
-  Returns the MySQL id.
-
-  Return type :
-
-  string
-
 =cut
 
 sub get_id {
@@ -132,10 +125,11 @@ sub get_id {
 
 =head2 get_cluster_id
 
-  $cluster_id = $cluster->get_cluster_id;
+Returns the cluster id of the cluster.
 
-  Returns the cluster id.
-  Return type: string
+Return type: string
+
+  $cluster_id = $cluster->get_cluster_id;
 
 =cut
 
@@ -146,10 +140,11 @@ sub get_cluster_id {
 
 =head2 get_promo_type
 
-  $pt = $cluster->get_promo_type;
+Returns the size of the promoter (500,1000,3000 bp).
 
-  Returns the size of the promoter (500,1000,3000 bp).
-  Return type: string
+Return type: string
+
+  $pt = $cluster->get_promo_type;
 
 =cut
 
@@ -160,11 +155,12 @@ sub get_promo_type {
 
 =head2 get_type
 
-  print $cluster->get_type;
+Returns the type of the promoter (The available return types are the following: 1,2,3,4,5n,6n). 
+See http://doop.abc.hu for more details.
 
-  Returns the type of the promoter (The available return types are the following: 1,2,3,4,5n,6n). 
-  See http://doop.abc.hu for more details.
-  Return type: string
+Return type: string
+
+  print $cluster->get_type;
 
 =cut
 
@@ -175,10 +171,11 @@ sub get_type {
 
 =head2 get_date
 
-  $date = $cluster->get_date;
+Returns the date when the cluster was last modified.
 
-  Returns the date when the cluster was last modified.
-  Return type: string
+Return type: string
+
+  $date = $cluster->get_date;
 
 =cut
 
@@ -189,10 +186,11 @@ sub get_date {
 
 =head2 get_version
 
-  print $cluster->get_version;
+Returns the version of the cluster.
 
-  Returns the version of the cluster.
-  Return type: string
+Return type: string
+
+  print $cluster->get_version;
 
 =cut
 
@@ -203,10 +201,11 @@ sub get_version {
 
 =head2 get_all_subsets
 
-  @subsets = @{$cluster->get_all_subsets};
+Returns the arrayref of all subsets associated with the cluster.
 
-  Returns the arrayref of all subsets associated with the cluster.
-  Return type: arrayref, the array containing Bio::DOOP::ClusterSubset objects
+Return type: arrayref, the array containing Bio::DOOP::ClusterSubset objects
+
+  @subsets = @{$cluster->get_all_subsets};
 
 =cut
 
@@ -229,14 +228,15 @@ sub get_all_subsets {
 
 =head2 get_subset_by_type
 
+Returns a subset of a cluster, specified by type.
+
+Return type: Bio::DOOP::ClusterSubset object
+
   $subset = $cluster->get_subset_by_type("B");
   if ($subset == -1){
-     print"No subset! Try another subset type\n";
+     print"No subsets! Try another subset type\n";
   }
 
-  Returns the subset specified by type.
-  Return type: Bio::DOOP::ClusterSubset object
-
 =cut
 
 sub get_subset_by_type {
@@ -256,10 +256,11 @@ sub get_subset_by_type {
 
 =head2 get_available_types
 
-  @types = @{$cluster->get_available_types};
+Returns all available cluster subset types.
 
-  Returns all available cluster subset types.
-  Return type: arrayref of string
+Return type: arrayref of strings
+
+  @types = @{$cluster->get_available_types};
 
 =cut
 
@@ -282,10 +283,11 @@ sub get_available_types {
 
 =head2 get_all_seqs
 
-  @seqs = @{$cluster->get_all_seqs};
+Returns the arrayref of all sequences associated with the cluster.
 
-  Returns the arrayref of all sequences associated with the cluster.
-  Return type: arrayref, the array containig Bio::DOOP::Sequence objects
+Return type: arrayref, the array containig Bio::DOOP::Sequence objects
+
+  @seqs = @{$cluster->get_all_seqs};
 
 =cut
 
@@ -308,10 +310,11 @@ sub get_all_seqs {
 
 =head2 get_orig_subset
 
-  @subsets = @{$cluster->get_orig_subset};
+Returns the original subset, containing the whole cluster.
 
-  Returns the original subset, containing the whole cluster.
-  Return type: Bio::DOOP::ClusterSubset object
+Return type: Bio::DOOP::ClusterSubset object
+
+  @subsets = @{$cluster->get_orig_subset};
 
 =cut
 
@@ -328,10 +331,11 @@ sub get_orig_subset {
 
 =head2 get_ref_seq
 
-  $refseq = $cluster->get_ref_seq;
+Returns the cluster reference sequence (human or arabidopsis).
 
-  Returns the cluster reference sequence (human or arabidopsis).
-  Return type: Bio::DOOP::Sequence object
+Return type: Bio::DOOP::Sequence object
+
+  $refseq = $cluster->get_ref_seq;
 
 =cut
 
